<?php
/*
Plugin Name: Login Logo Customizer
Plugin URI: https://example.com/login-logo-customizer
Description: Easily replace the default WordPress login page logo with a custom one.
Version: 1.0.0
Author: Your Name
Author URI: https://example.com
License: GPL2
*/

// Prevent direct access to the plugin
if (!defined('ABSPATH')) {
    exit;
}

class LoginLogoCustomizer
{
    private $option_name = 'login_logo_customizer';

    public function __construct()
    {
        // Hook into WordPress
        add_action('admin_menu', array($this, 'add_plugin_page'));
        add_action('admin_init', array($this, 'init_settings'));
        add_action('login_head', array($this, 'custom_login_logo'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_media_uploader'));
    }

    // Register the plugin settings page
    public function add_plugin_page()
    {
        add_options_page(
            'Login Logo Customizer',
            'Login Logo',
            'manage_options',
            'login-logo-customizer',
            array($this, 'create_admin_page')
        );
    }

    // Enqueue media uploader scripts
    public function enqueue_media_uploader($hook)
    {
        if ($hook !== 'settings_page_login-logo-customizer') {
            return;
        }
        wp_enqueue_media();
    }

    // Initialize settings
    public function init_settings()
    {
        register_setting(
            'login_logo_customizer_group',
            $this->option_name,
            array($this, 'sanitize')
        );

        add_settings_section(
            'login_logo_section',
            'Login Logo Settings',
            array($this, 'section_info'),
            'login-logo-customizer'
        );

        add_settings_field(
            'login_logo_url',
            'Logo Image',
            array($this, 'logo_url_callback'),
            'login-logo-customizer',
            'login_logo_section'
        );

        add_settings_field(
            'login_logo_width',
            'Logo Width',
            array($this, 'logo_width_callback'),
            'login-logo-customizer',
            'login_logo_section'
        );

        add_settings_field(
            'login_logo_height',
            'Logo Height',
            array($this, 'logo_height_callback'),
            'login-logo-customizer',
            'login_logo_section'
        );
    }

    // Sanitize input
    public function sanitize($input)
    {
        $new_input = array();

        if (isset($input['logo_url'])) {
            $new_input['logo_url'] = sanitize_text_field($input['logo_url']);
        }

        if (isset($input['logo_width'])) {
            $new_input['logo_width'] = absint($input['logo_width']);
        }

        if (isset($input['logo_height'])) {
            $new_input['logo_height'] = absint($input['logo_height']);
        }

        return $new_input;
    }

    // Section info callback
    public function section_info()
    {
        echo '<p>Customize the logo on your WordPress login page.</p>';
    }

    // Logo URL field callback
    public function logo_url_callback()
    {
        $options = get_option($this->option_name);
        $logo_url = isset($options['logo_url']) ? $options['logo_url'] : '';
        ?>
        <input type="text" id="login_logo_url" name="<?php echo $this->option_name; ?>[logo_url]"
            value="<?php echo esc_attr($logo_url); ?>" class="regular-text">
        <input type="button" class="button" id="upload_logo_button" value="Upload Logo">

        <script>
            jQuery(document).ready(function ($) {
                $('#upload_logo_button').click(function (e) {
                    e.preventDefault();
                    var image = wp.media({
                        title: 'Upload Logo',
                        multiple: false
                    }).open()
                        .on('select', function () {
                            var uploaded_image = image.state().get('selection').first();
                            var image_url = uploaded_image.toJSON().url;
                            $('#login_logo_url').val(image_url);
                        });
                });
            });
        </script>
        <?php
    }

    // Logo width field callback
    public function logo_width_callback()
    {
        $options = get_option($this->option_name);
        $logo_width = isset($options['logo_width']) ? $options['logo_width'] : 168;
        ?>
        <input type="number" id="login_logo_width" name="<?php echo $this->option_name; ?>[logo_width]"
            value="<?php echo esc_attr($logo_width); ?>" min="0" max="600" step="1" />
        <p class="description">Width in pixels (default: 168px)</p>
        <?php
    }

    // Logo height field callback
    public function logo_height_callback()
    {
        $options = get_option($this->option_name);
        $logo_height = isset($options['logo_height']) ? $options['logo_height'] : 168;
        ?>
        <input type="number" id="login_logo_height" name="<?php echo $this->option_name; ?>[logo_height]"
            value="<?php echo esc_attr($logo_height); ?>" min="0" max="600" step="1" />
        <p class="description">Height in pixels (default: 168px)</p>
        <?php
    }

    // Create admin page
    public function create_admin_page()
    {
        ?>
        <div class="wrap">
            <h1>Login Logo Customizer</h1>
            <form method="post" action="options.php">
                <?php
                settings_fields('login_logo_customizer_group');
                do_settings_sections('login-logo-customizer');
                submit_button();
                ?>
            </form>
        </div>
        <?php
    }

    // Custom login logo
    public function custom_login_logo()
    {
        $options = get_option($this->option_name);

        if (!empty($options['logo_url'])) {
            $width = !empty($options['logo_width']) ? $options['logo_width'] : 168;
            $height = !empty($options['logo_height']) ? $options['logo_height'] : 168;
            ?>
            <style type="text/css">
                .login h1 a {
                    background-image: url(<?php echo esc_url($options['logo_url']); ?>);
                    background-size:
                        <?php echo esc_attr($width); ?>
                        px
                        <?php echo esc_attr($height); ?>
                        px;
                    width:
                        <?php echo esc_attr($width); ?>
                        px;
                    height:
                        <?php echo esc_attr($height); ?>
                        px;
                }
            </style>
            <?php
        }
    }
}

// Initialize the plugin
function login_logo_customizer_init()
{
    new LoginLogoCustomizer();
}
add_action('plugins_loaded', 'login_logo_customizer_init');